'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _PageHandler = require('./PageHandler');

var _PageHandler2 = _interopRequireDefault(_PageHandler);

var _SerialBatch = require('../../execution/SerialBatch');

var _SerialBatch2 = _interopRequireDefault(_SerialBatch);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class PageHandlerRegistry extends _PageHandler2.default {
  /**
   * Creates an instance of HandlerRegistry and creates {@code SerialBatch}
   * instance for pre-handlers and post-handlers.
   *
   * @param {...PageManagerHandler} handlers
   * @memberof HandlerRegistry
   */
  constructor(...handlers) {
    super();

    this._preManageHandlers = new PageHandlerRegistry.ExecutionMethod(handlers.map(handler => handler.handlePreManagedState.bind(handler)));

    this._postManageHandlers = new PageHandlerRegistry.ExecutionMethod(handlers.map(handler => handler.handlePostManagedState.bind(handler)));
  }

  /**
   * Executes the pre-manage handlers with given arguments
   *
   * @param {ManagedPage} nextManagedPage
   * @param {ManagedPage} managedPage
   * @param {{ type: string, payload: Object|Event}} action
   * @return {Promise<any>}
   */
  handlePreManagedState(nextManagedPage, managedPage, action) {
    return this._preManageHandlers.execute(nextManagedPage, managedPage, action);
  }

  /**
   * Executes the post-manage handlers with given arguments
   *
   * @param {ManagedPage} previousManagedPage
   * @param {ManagedPage} managedPage
   * @param {{ type: string, payload: Object|Event}} action
   * @return {Promise<any>}
   */
  handlePostManagedState(previousManagedPage, managedPage, action) {
    return this._postManageHandlers.execute(previousManagedPage, managedPage, action);
  }
}

exports.default = PageHandlerRegistry;
PageHandlerRegistry.ExecutionMethod = _SerialBatch2.default;

typeof $IMA !== 'undefined' && $IMA !== null && $IMA.Loader && $IMA.Loader.register('ima/page/handler/PageHandlerRegistry', [], function (_export, _context) {
 'use strict';
 return {
   setters: [],
   execute: function () {
     _export('default', exports.default);
   }
 };
});
